@@ -11,8 +11,8 @@
 	General Public License for more details. (http://www.gnu.org/licenses/gpl.html)
 */
 
-#import <Cocoa/Cocoa.h>
-#import "SwordBible.h"
+#import <Foundation/Foundation.h>
+#import <ObjCSword/ObjCSword.h>
 
 #ifdef __cplusplus
 #include <rawfiles.h>
@@ -20,6 +20,8 @@ class sword::RawFiles;
 class sword::SWConfig;
 #endif
 
+
+
 @interface SwordCommentary : SwordBible {
 }
 
