@@ -6,8 +6,8 @@
 //  Copyright 2009 __MyCompanyName__. All rights reserved.
 //
 
+#import <ObjCSword/ObjCSword.h>
 #import "SwordListKeyTest.h"
-#import "ObjCSword/ObjCSword.h"
 
 @implementation SwordListKeyTest
 
@@ -41,7 +41,7 @@
     
     VerseEnumerator *ve = [lk verseEnumerator];
     int count = 0;
-    NSString *ref = nil;
+    NSString *ref;
     while((ref = [ve nextObject])) {
         count++;
     }
