@@ -1,10 +1,12 @@
 /******************************************************************************
- * This is a dumby program which does nothing useful but links to the
- * SWORD engine to confirm basic things were built ok.
  *
- * $Id: buildtest.cpp 2327 2009-04-22 11:42:33Z scribe $
+ *  buildtest.cpp -	This is a dumby program which does nothing useful but
+ *			links to the SWORD engine to confirm basic things were
+ *			built ok.
  *
- * Copyright 1998-2009 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: buildtest.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 1999-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -50,13 +52,13 @@ int main(int argc, char **argv)
 
 
 	if (argc > 3)
-		mykey.AutoNormalize(0);  // Turn off autonormalize if 3 args to allow for intros
+		mykey.setAutoNormalize(false);  // Turn off autonormalize if 3 args to allow for intros
 				// This is kludgy but at lease you can try it
 				// with something like: sword "Matthew 1:0" 1 1
 
 
 	mykey = (argc < 2) ? "James    1:19" : argv[1];
-	mykey.Persist(1);
+	mykey.setPersist(true);
 	text.setKey(mykey);
 	commentary.setKey(mykey);
 
@@ -69,10 +71,10 @@ int main(int argc, char **argv)
 
 	for (loop = 0; loop < max; loop++) {
 		cout << (SWKey &)text << ":\n";
-		text.Display();
+		text.display();
 		cout << "\n";
 		cout << "-------------\n";
-		commentary.Display();
+		commentary.display();
 		cout << "\n";
 		cout << "==========================\n";
 		mykey++;
