@@ -1,5 +1,7 @@
 /******************************************************************************
- * This is about the simplest useful example of using the sword engine.
+ *
+ *  simple.cpp -	This is about the simplest useful example of using the
+ *			SWORD engine.
  *
  * After sword is installed, it should compile with something similar to:
  *
@@ -14,9 +16,9 @@
  *
  *	SWMgr library(0, 0, true, new MarkupFilterMgr(FMT_HTMLHREF));
  *
- * $Id: swmgr.h 2321 2009-04-13 01:17:00Z scribe $
+ * $Id: simple.cpp 2980 2013-09-14 21:51:47Z scribe $
  *
- * Copyright 1998-2009 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 2006-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -36,9 +38,11 @@
 #include <swmodule.h>
 #include <iostream>
 
+
 using namespace sword;
 using std::cout;
 
+
 int main(int argc, char **argv) {
 	SWMgr library;
 	SWModule *darby = library.getModule("Darby");
@@ -47,3 +51,4 @@ int main(int argc, char **argv) {
 
 	return 0;
 }
+
