@@ -1,8 +1,10 @@
 /******************************************************************************
  *
- * $Id: gbfhtmlhref.h 1688 2005-01-01 04:42:26Z scribe $
+ *  gbfhtmlhref.h -	Implementation of GBFHTMLHREF
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: gbfhtmlhref.h 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -28,6 +30,7 @@ SWORD_NAMESPACE_START
 /** this filter converts GBF  text to HTML text with hrefs
  */
 class SWDLLEXPORT GBFHTMLHREF : public SWBasicFilter {
+	bool renderNoteNumbers;
 protected:
 	class MyUserData : public BasicFilterUserData {
 	public:
@@ -41,6 +44,7 @@ protected:
 	virtual bool handleToken(SWBuf &buf, const char *token, BasicFilterUserData *userData);
 public:
 	GBFHTMLHREF();
+	void setRenderNoteNumbers(bool val = true) { renderNoteNumbers = val; }
 };
 
 SWORD_NAMESPACE_END
