@@ -1,8 +1,10 @@
 /******************************************************************************
  *
- * $Id: gbfwebif.h,v 1.5 2003/08/12 05:36:30 scribe Exp $
+ *  gbfwebif.h -	Implementation of GBFWEBIF
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: gbfwebif.h 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2003-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -21,13 +23,13 @@
 #ifndef GBFWEBIF_H
 #define GBFWEBIF_H
 
-#include <gbfhtmlhref.h>
+#include <gbfxhtml.h>
 
 SWORD_NAMESPACE_START
 
-/** this filter converts GBF  text to HTML text with hrefs
+/** this filter converts GBF text to classed XHTML for web interfaces
  */
-class SWDLLEXPORT GBFWEBIF : public GBFHTMLHREF {
+class SWDLLEXPORT GBFWEBIF : public GBFXHTML {
 	const SWBuf baseURL;
 	const SWBuf passageStudyURL;
 
