@@ -1,8 +1,10 @@
 /******************************************************************************
  *
- * $Id: osiswebif.h 1946 2006-07-15 20:41:24Z scribe $
+ *  osiswebif.h -	Implementation of OSISWEBIF
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: osiswebif.h 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2003-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -21,20 +23,19 @@
 #ifndef OSISWEBIF_H
 #define OSISWEBIF_H
 
-#include <osishtmlhref.h>
+#include <osisxhtml.h>
 
 SWORD_NAMESPACE_START
 
 /** this filter converts OSIS  text to HTML text with hrefs
  */
-class SWDLLEXPORT OSISWEBIF : public OSISHTMLHREF {
+class SWDLLEXPORT OSISWEBIF : public OSISXHTML {
 	const SWBuf baseURL;
 	const SWBuf passageStudyURL;
 	bool javascript;
 
 protected:
 	virtual bool handleToken(SWBuf &buf, const char *token, BasicFilterUserData *userData);
-	virtual BasicFilterUserData *createUserData(const SWModule *module, const SWKey *key);
 public:
 	OSISWEBIF();
 	void setJavascript(bool mode) { javascript = mode; }
