@@ -1,8 +1,12 @@
 /******************************************************************************
- *  swdisp.cpp  - code for base class 'swdisp'.  swdisp is the basis for all
- *		  types of displays (e.g. raw textout, curses, xwindow, etc.)
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *  swdisp.cpp -	code for base class 'SWDisplay'.  SWDisplay is the
+ *			basis for all types of displays (e.g. raw textout,
+ *			curses, xwindow, etc.)
+ *
+ * $Id: swdisp.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 1996-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -19,9 +23,6 @@
  */
 
 
-#ifndef	_WIN32_WCE
-#include <iostream>
-#endif
 #include <swmodule.h>
 #include <swdisp.h>
 
@@ -40,12 +41,5 @@ SWClass SWDisplay::classdef(classes);
  * RET:	error status
  */
 
-char SWDisplay::Display(SWModule &imodule)
-{
-#ifndef	_WIN32_WCE
-	std::cout << (const char *)imodule;
-#endif
-	return 0;
-}
 
 SWORD_NAMESPACE_END
