@@ -1,10 +1,11 @@
 /******************************************************************************
- *  filemgr.cpp	- implementation of class FileMgr used for pooling file
- *  					handles
  *
- * $Id: filemgr.cpp 2495 2009-12-24 22:22:16Z scribe $
+ *  filemgr.cpp -	implementation of class FileMgr used for pooling file
+ *			handles
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: filemgr.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 1998-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -540,12 +541,18 @@ int FileMgr::removeDir(const char *targetDir) {
 					FileMgr::removeFile(targetPath.c_str());
 				}
 				else {
-					removeDir(targetPath.c_str());
+					FileMgr::removeDir(targetPath.c_str());
 				}
 			}
 		}
 		closedir(dir);
-		removeFile(targetDir);
+		FileMgr::removeFile(targetDir);
+/*
+		int status = FileMgr::removeFile(targetDir);
+          int stuff = errno;
+          char *err = strerror(errno);
+          int x = stuff;
+*/
 	}
 	return 0;
 }
