@@ -1,10 +1,10 @@
- /*****************************************************************************
- * InstallMgr functions to be made into something usefully exposed by
- * master Glassey
+/*****************************************************************************
  *
+ *  installmgr.cpp -	InstallMgr functions
  *
+ * $Id: installmgr.cpp 2980 2013-09-14 21:51:47Z scribe $
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 2002-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -20,8 +20,6 @@
  *
  */
 
-
-
 #ifndef EXCLUDEZLIB
 extern "C" {
 #include <untgz.h>
@@ -51,23 +49,26 @@ extern "C" {
 #endif
 
 #include <iostream>
+
+
+using std::map;
+
+
 SWORD_NAMESPACE_START
 
 namespace {
 
-void removeTrailingSlash(SWBuf &buf) {
-	int len = buf.size();
-	if ((buf[len-1] == '/')
-	 || (buf[len-1] == '\\'))
-		buf.size(len-1);
+	static void removeTrailingSlash(SWBuf &buf) {
+		int len = buf.size();
+		if ((buf[len-1] == '/')
+		 || (buf[len-1] == '\\'))
+			buf.size(len-1);
+	}
+
+	static const char *masterRepoList = "masterRepoList.conf";
+
 }
 
-const char *masterRepoList = "masterRepoList.conf";
-
-};
-
-
-using std::map;
 
 const int InstallMgr::MODSTAT_OLDER            = 0x001;
 const int InstallMgr::MODSTAT_SAMEVERSION      = 0x002;
@@ -76,10 +77,11 @@ const int InstallMgr::MODSTAT_NEW              = 0x008;
 const int InstallMgr::MODSTAT_CIPHERED         = 0x010;
 const int InstallMgr::MODSTAT_CIPHERKEYPRESENT = 0x020;
 
-// override this method and provide your own custom FTPTransport subclass
+
+// override this method and provide your own custom RemoteTransport subclass
 // here we try a couple defaults if sword was compiled with support for them.
 // see these classes for examples of how to make your own
-FTPTransport *InstallMgr::createFTPTransport(const char *host, StatusReporter *statusReporter) {
+RemoteTransport *InstallMgr::createFTPTransport(const char *host, StatusReporter *statusReporter) {
 #ifdef CURLAVAILABLE
 	return new CURLFTPTransport(host, statusReporter);
 #else
@@ -87,7 +89,8 @@ FTPTransport *InstallMgr::createFTPTransport(const char *host, StatusReporter *s
 #endif
 }
 
-FTPTransport *InstallMgr::createHTTPTransport(const char *host, StatusReporter *statusReporter) {
+
+RemoteTransport *InstallMgr::createHTTPTransport(const char *host, StatusReporter *statusReporter) {
 #ifdef CURLAVAILABLE
 	return new CURLHTTPTransport(host, statusReporter);
 #else
@@ -96,7 +99,6 @@ FTPTransport *InstallMgr::createHTTPTransport(const char *host, StatusReporter *
 }
 
 
-
 InstallMgr::InstallMgr(const char *privatePath, StatusReporter *sr, SWBuf u, SWBuf p) {
 	userDisclaimerConfirmed = false;
 	statusReporter = sr;
@@ -125,6 +127,7 @@ InstallMgr::~InstallMgr() {
 	clearSources();
 }
 
+
 void InstallMgr::clearSources() {
 	for (InstallSourceMap::iterator it = sources.begin(); it != sources.end(); ++it) {
 		delete it->second;
@@ -132,6 +135,7 @@ void InstallMgr::clearSources() {
 	sources.clear();
 }
 
+
 void InstallMgr::readInstallConf() {
 
 	if (installConf) delete installConf;
@@ -147,6 +151,7 @@ void InstallMgr::readInstallConf() {
 	ConfigEntMap::iterator sourceEnd;
 
 	if (confSection != installConf->Sections.end()) {
+
 		sourceBegin = confSection->second.lower_bound("FTPSource");
 		sourceEnd = confSection->second.upper_bound("FTPSource");
 
@@ -158,6 +163,21 @@ void InstallMgr::readInstallConf() {
 			is->localShadow = (SWBuf)privatePath + "/" + is->uid;
 			sourceBegin++;
 		}
+
+#ifdef CURLSFTPAVAILABLE
+		sourceBegin = confSection->second.lower_bound("SFTPSource");
+		sourceEnd   = confSection->second.upper_bound("SFTPSource");
+
+		while (sourceBegin != sourceEnd) {
+			InstallSource *is = new InstallSource("SFTP", sourceBegin->second.c_str());
+			sources[is->caption] = is;
+			SWBuf parent = (SWBuf)privatePath + "/" + is->uid + "/file";
+			FileMgr::createParent(parent.c_str());
+			is->localShadow = (SWBuf)privatePath + "/" + is->uid;
+			sourceBegin++;
+		}
+#endif // CURLSFTPAVAILABLE
+
 		sourceBegin = confSection->second.lower_bound("HTTPSource");
 		sourceEnd = confSection->second.upper_bound("HTTPSource");
 
@@ -169,6 +189,18 @@ void InstallMgr::readInstallConf() {
 			is->localShadow = (SWBuf)privatePath + "/" + is->uid;
 			sourceBegin++;
 		}
+
+		sourceBegin = confSection->second.lower_bound("HTTPSSource");
+		sourceEnd   = confSection->second.upper_bound("HTTPSSource");
+
+		while (sourceBegin != sourceEnd) {
+			InstallSource *is = new InstallSource("HTTPS", sourceBegin->second.c_str());
+			sources[is->caption] = is;
+			SWBuf parent = (SWBuf)privatePath + "/" + is->uid + "/file";
+			FileMgr::createParent(parent.c_str());
+			is->localShadow = (SWBuf)privatePath + "/" + is->uid;
+			sourceBegin++;
+		}
 	}
 
 	defaultMods.clear();
@@ -270,19 +302,24 @@ int InstallMgr::removeModule(SWMgr *manager, const char *moduleName) {
 
 
 // TODO: rename to netCopy
-int InstallMgr::ftpCopy(InstallSource *is, const char *src, const char *dest, bool dirTransfer, const char *suffix) {
-SWLog::getSystemLog()->logDebug("netCopy: %s, %s, %s, %c, %s", (is?is->source.c_str():"null"), src, (dest?dest:"null"), (dirTransfer?'t':'f'), (suffix?suffix:"null"));
+int InstallMgr::remoteCopy(InstallSource *is, const char *src, const char *dest, bool dirTransfer, const char *suffix) {
+SWLog::getSystemLog()->logDebug("remoteCopy: %s, %s, %s, %c, %s", (is?is->source.c_str():"null"), src, (dest?dest:"null"), (dirTransfer?'t':'f'), (suffix?suffix:"null"));
 
 	// assert user disclaimer has been confirmed
 	if (!isUserDisclaimerConfirmed()) return -1;
 
 	int retVal = 0;
-	FTPTransport *trans = 0;
-	if (is->type == "FTP") {
+	RemoteTransport *trans = 0;
+	if (is->type == "FTP" 
+#ifdef CURLSFTPAVAILABLE
+		|| is->type == "SFTP"
+#endif
+		) {
+
 		trans = createFTPTransport(is->source, statusReporter);
 		trans->setPassive(passive);
 	}
-	else if (is->type == "HTTP") {
+	else if (is->type == "HTTP" || is->type == "HTTPS") {
 		trans = createHTTPTransport(is->source, statusReporter);
 	}
 	transport = trans; // set classwide current transport for other thread terminate() call
@@ -295,7 +332,22 @@ SWLog::getSystemLog()->logDebug("netCopy: %s, %s, %s, %c, %s", (is?is->source.c_
 		trans->setPasswd(p);
 	}
 
-	SWBuf urlPrefix = (SWBuf)((is->type == "HTTP") ? "http://" : "ftp://") + is->source;
+	SWBuf urlPrefix;
+	if (is->type == "HTTP") {
+		urlPrefix = (SWBuf) "http://";
+	}
+	else if (is->type == "HTTPS") {
+		urlPrefix = (SWBuf) "https://";
+	}
+#ifdef CURLSFTPAVAILABLE
+	else if (is->type == "SFTP") {
+		urlPrefix = (SWBuf) "sftp://";
+	}
+#endif
+	else {
+		urlPrefix = (SWBuf) "ftp://";
+	}
+	urlPrefix.append(is->source);
 
 	// let's be sure we can connect.  This seems to be necessary but sucks
 //	SWBuf url = urlPrefix + is->directory.c_str() + "/"; //dont forget the final slash
@@ -329,7 +381,7 @@ SWLog::getSystemLog()->logDebug("netCopy: %s, %s, %s, %c, %s", (is?is->source.c_
 		}
 	}
 	SWTRY {
-		FTPTransport *deleteMe = trans;
+		RemoteTransport *deleteMe = trans;
 		// do this order for threadsafeness
 		// (see terminate())
 		trans = transport = 0;
@@ -386,7 +438,7 @@ int InstallMgr::installModule(SWMgr *destMgr, const char *fromLocation, const ch
 			if (is) {
 				while (fileBegin != fileEnd) {	// netCopy each file first
 					buffer = sourceDir + fileBegin->second.c_str();
-					if (ftpCopy(is, fileBegin->second.c_str(), buffer.c_str())) {
+					if (remoteCopy(is, fileBegin->second.c_str(), buffer.c_str())) {
 						aborted = true;
 						break;	// user aborted
 					}
@@ -446,7 +498,7 @@ int InstallMgr::installModule(SWMgr *destMgr, const char *fromLocation, const ch
 				SWLog::getSystemLog()->logDebug("***** relativePath: %s \n", relativePath.c_str());
 
 				if (is) {
-					if (ftpCopy(is, relativePath.c_str(), absolutePath.c_str(), true)) {
+					if (remoteCopy(is, relativePath.c_str(), absolutePath.c_str(), true)) {
 						aborted = true;	// user aborted
 					}
 				}
@@ -498,6 +550,7 @@ int InstallMgr::installModule(SWMgr *destMgr, const char *fromLocation, const ch
 	return 1;
 }
 
+
 int InstallMgr::refreshRemoteSource(InstallSource *is) {
 
 	// assert user disclaimer has been confirmed
@@ -516,7 +569,7 @@ int InstallMgr::refreshRemoteSource(InstallSource *is) {
 #ifndef EXCLUDEZLIB
 	SWBuf archive = root + "/mods.d.tar.gz";
 
-	errorCode = ftpCopy(is, "mods.d.tar.gz", archive.c_str(), false);
+	errorCode = remoteCopy(is, "mods.d.tar.gz", archive.c_str(), false);
 	if (!errorCode) { //sucessfully downloaded the tar,gz of module configs
 		FileDesc *fd = FileMgr::getSystemFileMgr()->open(archive.c_str(), FileMgr::RDONLY);
 		untargz(fd->getFd(), root.c_str());
@@ -524,7 +577,7 @@ int InstallMgr::refreshRemoteSource(InstallSource *is) {
 	}
 	else
 #endif
-	errorCode = ftpCopy(is, "mods.d", target.c_str(), true, ".conf"); //copy the whole directory
+	errorCode = remoteCopy(is, "mods.d", target.c_str(), true, ".conf"); //copy the whole directory
 
 	is->flush();
 	return errorCode;
@@ -535,6 +588,7 @@ bool InstallMgr::isDefaultModule(const char *modName) {
 	return defaultMods.count(modName);
 }
 
+
 /************************************************************************
  * getModuleStatus - compare the modules of two SWMgrs and return a 
  * 	vector describing the status of each.  See MODSTAT_*
@@ -603,7 +657,7 @@ int InstallMgr::refreshRemoteSourceConfiguration() {
 	InstallSource is("FTP");
 	is.source = "ftp.crosswire.org";
 	is.directory = "/pub/sword";
-	int errorCode = ftpCopy(&is, masterRepoList, masterRepoListPath.c_str(), false);
+	int errorCode = remoteCopy(&is, masterRepoList, masterRepoListPath.c_str(), false);
 	if (!errorCode) { //sucessfully downloaded the repo list
 		SWConfig masterList(masterRepoListPath);
 		SectionMap::iterator sections = masterList.Sections.find("Repos");
