@@ -1,6 +1,25 @@
 /******************************************************************************
- *  rawcom.cpp - code for class 'RawCom'- a module that reads raw commentary
- *			files:	ot and nt using indexs ??.bks ??.cps ??.vss
+ *
+ *  rawcom.cpp -	code for class 'RawCom'- a module that reads raw
+ *			commentary files:
+ *			ot and nt using indexs ??.bks ??.cps ??.vss
+ *
+ * $Id: rawcom.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 1997-2013 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
 
@@ -23,9 +42,9 @@ SWORD_NAMESPACE_START
  *	idisp	 - Display object to use for displaying
  */
 
-RawCom::RawCom(const char *ipath, const char *iname, const char *idesc, SWDisplay *idisp, SWTextEncoding encoding, SWTextDirection dir, SWTextMarkup markup, const char* ilang)
+RawCom::RawCom(const char *ipath, const char *iname, const char *idesc, SWDisplay *idisp, SWTextEncoding encoding, SWTextDirection dir, SWTextMarkup markup, const char *ilang, const char *versification)
 		: RawVerse(ipath),
-            SWCom(iname, idesc, idisp, encoding, dir, markup, ilang){
+            SWCom(iname, idesc, idisp, encoding, dir, markup, ilang, versification) {
 }
 
 
@@ -38,7 +57,7 @@ RawCom::~RawCom()
 }
 
 
-bool RawCom::isWritable() {
+bool RawCom::isWritable() const {
 	return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & FileMgr::RDWR) == FileMgr::RDWR));
 }
 /******************************************************************************
@@ -48,16 +67,16 @@ bool RawCom::isWritable() {
  * RET: string buffer with verse
  */
 
-SWBuf &RawCom::getRawEntryBuf() {
+SWBuf &RawCom::getRawEntryBuf() const {
 	long  start = 0;
 	unsigned short size = 0;
 	VerseKey *key = &getVerseKey();
 
-	findOffset(key->Testament(), key->Index(), &start, &size);
+	findOffset(key->getTestament(), key->getTestamentIndex(), &start, &size);
 	entrySize = size;        // support getEntrySize call
 
 	entryBuf = "";
-	readText(key->Testament(), start, size, entryBuf);
+	readText(key->getTestament(), start, size, entryBuf);
 
 	rawFilter(entryBuf, 0);	// hack, decipher
 	rawFilter(entryBuf, key);
@@ -82,22 +101,22 @@ void RawCom::increment(int steps) {
 	unsigned short size;
 	VerseKey *tmpkey = &getVerseKey();
 
-	findOffset(tmpkey->Testament(), tmpkey->Index(), &start, &size);
+	findOffset(tmpkey->getTestament(), tmpkey->getTestamentIndex(), &start, &size);
 
 	SWKey lastgood = *tmpkey;
 	while (steps) {
 		long laststart = start;
 		unsigned short lastsize = size;
 		SWKey lasttry = *tmpkey;
-		(steps > 0) ? (*key)++ : (*key)--;
+		(steps > 0) ? ++(*key) : --(*key);
 		tmpkey = &getVerseKey();
 
-		if ((error = key->Error())) {
+		if ((error = key->popError())) {
 			*key = lastgood;
 			break;
 		}
-		long index = tmpkey->Index();
-		findOffset(tmpkey->Testament(), index, &start, &size);
+		long index = tmpkey->getTestamentIndex();
+		findOffset(tmpkey->getTestament(), index, &start, &size);
 		if (
 			(((laststart != start) || (lastsize != size))	// we're a different entry
 //				&& (start > 0)
@@ -113,24 +132,15 @@ void RawCom::increment(int steps) {
 
 void RawCom::setEntry(const char *inbuf, long len) {
 	VerseKey *key = &getVerseKey();
-	doSetText(key->Testament(), key->Index(), inbuf, len);
+	doSetText(key->getTestament(), key->getTestamentIndex(), inbuf, len);
 }
 
 
 void RawCom::linkEntry(const SWKey *inkey) {
 	VerseKey *destkey = &getVerseKey();
-	const VerseKey *srckey = 0;
+	const VerseKey *srckey = &getVerseKey(inkey);
 
-	// see if we have a VerseKey * or decendant
-	SWTRY {
-		srckey = SWDYNAMIC_CAST(VerseKey, inkey);
-	}
-	SWCATCH ( ... ) {}
-	// if we don't have a VerseKey * decendant, create our own
-	if (!srckey)
-		srckey = new VerseKey(inkey);
-
-	doLinkEntry(destkey->Testament(), destkey->Index(), srckey->Index());
+	doLinkEntry(destkey->getTestament(), destkey->getTestamentIndex(), srckey->getTestamentIndex());
 
 	if (inkey != srckey) // free our key if we created a VerseKey
 		delete srckey;
@@ -146,8 +156,29 @@ void RawCom::linkEntry(const SWKey *inkey) {
 void RawCom::deleteEntry() {
 
 	VerseKey *key = &getVerseKey();
-	doSetText(key->Testament(), key->Index(), "");
+	doSetText(key->getTestament(), key->getTestamentIndex(), "");
 }
 
+bool RawCom::isLinked(const SWKey *k1, const SWKey *k2) const {
+	long start1, start2;
+	unsigned short size1, size2;
+	VerseKey *vk1 = &getVerseKey(k1);
+	VerseKey *vk2 = &getVerseKey(k2);
+	if (vk1->getTestament() != vk2->getTestament()) return false;
+
+	findOffset(vk1->getTestament(), vk1->getTestamentIndex(), &start1, &size1);
+	findOffset(vk2->getTestament(), vk2->getTestamentIndex(), &start2, &size2);
+	if (!size1 || !size2) return false;
+	return start1 == start2;
+}
+
+bool RawCom::hasEntry(const SWKey *k) const {
+	long start;
+	unsigned short size;
+	VerseKey *vk = &getVerseKey(k);
+
+	findOffset(vk->getTestament(), vk->getTestamentIndex(), &start, &size);
+	return size;
+}
 
 SWORD_NAMESPACE_END
