@@ -1,10 +1,11 @@
 /******************************************************************************
  *
- * gbfplain -	SWFilter descendant to strip out all GBF tags or convert to
- *		ASCII rendered symbols.
+ *  gbfplain.cpp -	SWFilter descendant to strip out all GBF tags or
+ *			convert to ASCII rendered symbols
  *
+ * $Id: gbfplain.cpp 2980 2013-09-14 21:51:47Z scribe $
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 1997-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -24,8 +25,10 @@
 #include <gbfplain.h>
 #include <swbuf.h>
 
+
 SWORD_NAMESPACE_START
 
+
 GBFPlain::GBFPlain() {
 }
 
@@ -109,4 +112,6 @@ char GBFPlain::processText (SWBuf &text, const SWKey *key, const SWModule *modul
 	return 0;
 }
 
+
 SWORD_NAMESPACE_END
+
