@@ -1,10 +1,26 @@
 /******************************************************************************
  *
- * greeklexattribs -	SWFilter descendant to set entry attributes for greek
- * 	                lexicons
+ *  greeklexattribs.cpp -	SWFilter descendant to set entry attributes
+ *				for greek lexicons
+ *
+ * $Id: greeklexattribs.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2002-2013 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
