@@ -1,10 +1,10 @@
 /***************************************************************************
- *                    osisosis.cpp  -  internal OSIS to public OSIS filter
- *                            -------------------
- *   begin                : 2004-03-13
- *   copyright            : 2003 by CrossWire Bible Society
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ *  osisosis.cpp -	internal OSIS to public OSIS filter
+ *
+ * $Id: osisosis.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2004-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -59,7 +59,7 @@ char OSISOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 	VerseKey *vkey = SWDYNAMIC_CAST(VerseKey, key);
 	if (vkey) {
 		SWBuf ref = "";
-		if (vkey->Verse()) {
+		if (vkey->getVerse()) {
 			ref.appendFormatted("\t\t<verse osisID=\"%s\">", vkey->getOSISRef());
 		}
 
@@ -67,24 +67,24 @@ char OSISOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 
 			text = ref + text;
 
-			if (vkey->Verse()) {
+			if (vkey->getVerse()) {
 				VerseKey *tmp = (VerseKey *)vkey->clone();
 				*tmp = *vkey;
-				tmp->AutoNormalize(0);
-				tmp->Headings(1);
+				tmp->setAutoNormalize(false);
+				tmp->setIntros(true);
 
 				text += "</verse>";
 
 				*tmp = MAXVERSE;
 				if (*vkey == *tmp) {
-					tmp->Verse(0);
+					tmp->setVerse(0);
 //					sprintf(ref, "\t</div>");
 //					pushString(&to, ref);
 					*tmp = MAXCHAPTER;
 					*tmp = MAXVERSE;
 					if (*vkey == *tmp) {
-						tmp->Chapter(0);
-						tmp->Verse(0);
+						tmp->setChapter(0);
+						tmp->setVerse(0);
 //						sprintf(ref, "\t</div>");
 //						pushString(&to, ref);
 					}
