@@ -2,7 +2,7 @@
  *
  *  osisplain.cpp -	An SWFilter that provides stripping of OSIS tags
  *
- * $Id: osisplain.cpp 2984 2013-09-20 12:18:45Z scribe $
+ * $Id: osisplain.cpp 3156 2014-04-17 03:50:37Z greg.hellings $
  *
  * Copyright 2003-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -185,7 +185,7 @@ bool OSISPlain::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 		// Milestoned paragraph, created by osis2mod
 		// <div type="paragraph"  sID... />
 		// <div type="paragraph"  eID... />
-		else if (!strcmp(u->tag.getName(), "div") && u->tag.getAttribute("type") && !strcmp(u->tag.getAttribute("type"), "paragraph") &&
+		else if (!strcmp(u->tag.getName(), "div") && u->tag.getAttribute("type") && (!strcmp(u->tag.getAttribute("type"), "x-p") || !strcmp(u->tag.getAttribute("type"), "paragraph")) &&
 			(u->tag.isEmpty() && (u->tag.getAttribute("sID") || u->tag.getAttribute("eID")))) {
 				userData->supressAdjacentWhitespace = true;
 				buf.append('\n');
