@@ -1,10 +1,26 @@
 /******************************************************************************
  *
- * SCSUUTF8 -	SWFilter descendant to convert a SCSU character to UTF-8
+ *  scsuutf8.cpp -	SWFilter descendant to convert a SCSU character to
+ *			UTF-8
+ *
+ * $Id: scsuutf8.cpp 2980 2013-09-14 21:51:47Z scribe $
+ *
+ * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  */
 
-
 /* This class is based on:
  * http://czyborra.com/scsu/scsu.c written by Roman Czyborra@dds.nl
  * on Andrea's balcony in North Amsterdam on 1998-08-04
@@ -22,8 +38,10 @@
 
 #include <scsuutf8.h>
 
+
 SWORD_NAMESPACE_START
 
+
 SCSUUTF8::SCSUUTF8() {
 }
 
@@ -61,6 +79,7 @@ unsigned char* SCSUUTF8::UTF8Output(unsigned long uchar, unsigned char* text)
   return text;
 }
 
+
 char SCSUUTF8::processText(SWBuf &text, const SWKey *key, const SWModule *module) {
 /*
   unsigned char *to, *from;
@@ -223,4 +242,5 @@ char SCSUUTF8::processText(SWBuf &text, const SWKey *key, const SWModule *module
   return 0;
 }
 
+
 SWORD_NAMESPACE_END
