@@ -2,7 +2,7 @@
  *
  *  teihtmlhref.cpp -	TEI to HTML with hrefs filter
  *
- * $Id: teihtmlhref.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: teihtmlhref.cpp 3160 2014-04-17 04:02:17Z greg.hellings $
  *
  * Copyright 2008-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -87,26 +87,29 @@ bool TEIHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData
 				SWBuf rend = tag.getAttribute("rend");
 				
 				u->lastHi = rend;
-				if (rend == "ital")
-					buf += "<i>";
-				else if (rend == "italic")
+				if (rend == "italic" || rend == "ital")
 					buf += "<i>";
 				else if (rend == "bold")
 					buf += "<b>";
-				else if (rend == "sup")
-					buf += "<small><sup>";
-
+				else if (rend == "super" || rend == "sup")
+					buf += "<sup>";
+				else if (rend == "sub")
+					buf += "<sub>";
+				else if (rend == "overline")
+					buf += "<span style=\"text-decoration:overline\">";
 			}
 			else if (tag.isEndTag()) {
 				SWBuf rend = u->lastHi;
-				if (rend == "ital")
-					buf += "</i>";
-				else if (rend == "italic")
+				if (rend == "italic" || rend == "ital")
 					buf += "</i>";
 				else if (rend == "bold")
 					buf += "</b>";
-				else if (rend == "sup")
-					buf += "</sup></small>";
+				else if (rend == "super" || rend == "sup")
+					buf += "</sup>";
+				else if (rend == "sub")
+					buf += "</sub>";
+				else if (rend == "overline")
+					buf += "</span>";
 			}
 		}
 
