@@ -1,10 +1,10 @@
 /******************************************************************************
  *
- * thmlstrongs -	SWFilter descendant to hide or show strongs number
- *			in a ThML module.
+ *  thmlosis.cpp -	filter to convert ThML to OSIS
  *
+ * $Id: thmlosis.cpp 2833 2013-06-29 06:40:28Z chrislit $
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 2002-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -540,7 +540,7 @@ char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 	VerseKey *vkey = SWDYNAMIC_CAST(VerseKey, key);
 	if (vkey) {
 		SWBuf ref = "";
-		if (vkey->Verse()) {
+		if (vkey->getVerse()) {
 			ref.appendFormatted("\t\t<verse osisID=\"%s\">", vkey->getOSISRef());
 		}
 			
@@ -548,24 +548,24 @@ char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 			
 			text = ref + text;
 			
-			if (vkey->Verse()) {
+			if (vkey->getVerse()) {
 				VerseKey *tmp = (VerseKey *)vkey->clone();
 				*tmp = *vkey;
-				tmp->AutoNormalize(0);
-				tmp->Headings(1);
+				tmp->setAutoNormalize(false);
+				tmp->setIntros(true);
 
 				text += "</verse>";
 
 				*tmp = MAXVERSE;
 				if (*vkey == *tmp) {
-					tmp->Verse(0);
+					tmp->setVerse(0);
 //					sprintf(ref, "\t</div>");
 //					pushString(&to, ref);
 					*tmp = MAXCHAPTER;
 					*tmp = MAXVERSE;
 					if (*vkey == *tmp) {
-						tmp->Chapter(0);
-						tmp->Verse(0);
+						tmp->setChapter(0);
+						tmp->setVerse(0);
 //						sprintf(ref, "\t</div>");
 //						pushString(&to, ref);
 /*
@@ -578,7 +578,7 @@ char ThMLOSIS::processText(SWBuf &text, const SWKey *key, const SWModule *module
 				}
                                 delete tmp;
 			}
-//			else if (vkey->Chapter()) {
+//			else if (vkey->getChapter()) {
 //				sprintf(ref, "\t<div type=\"chapter\" osisID=\"%s\">", vkey->getOSISRef());
 //			}
 //			else sprintf(ref, "\t<div type=\"book\" osisID=\"%s\">", vkey->getOSISRef());
