@@ -3,9 +3,9 @@
  *  thmlscripref.cpp -	SWFilter descendant to hide or show scripture
  *			referebces in a ThML module
  *
- * $Id: thmlscripref.cpp 2980 2013-09-14 21:51:47Z scribe $
+ * $Id: thmlscripref.cpp 3156 2014-04-17 03:50:37Z greg.hellings $
  *
- * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 2001-2014 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -37,7 +37,7 @@ namespace {
 	static const char oTip[]  = "Toggles Scripture Cross-references On and Off if they exist";
 
 	static const StringList *oValues() {
-		static const SWBuf choices[3] = {"On", "Off", ""};
+		static const SWBuf choices[3] = {"Off", "On", ""};
 		static const StringList oVals(&choices[0], &choices[2]);
 		return &oVals;
 	}
