@@ -1,10 +1,11 @@
 /******************************************************************************
  *
- * thmlstrongs -	SWFilter descendant to hide or show strongs number
- *			in a ThML module.
+ *  thmlstrongs.cpp -	SWFilter descendant to hide or show Strong's number
+ *			in a ThML module
  *
+ * $Id: thmlstrongs.cpp 2980 2013-09-14 21:51:47Z scribe $
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -27,16 +28,23 @@
 #include <utilstr.h>
 #include <ctype.h>
 
+
 SWORD_NAMESPACE_START
 
-const char oName[] = "Strong's Numbers";
-const char oTip[] = "Toggles Strong's Numbers On and Off if they exist";
+namespace {
 
-const SWBuf choices[3] = {"Off", "On", ""};
-const StringList oValues(&choices[0], &choices[2]);
+	static const char oName[] = "Strong's Numbers";
+	static const char oTip[]  = "Toggles Strong's Numbers On and Off if they exist";
 
-ThMLStrongs::ThMLStrongs() : SWOptionFilter(oName, oTip, &oValues) {
-	setOptionValue("Off");
+	static const StringList *oValues() {
+		static const SWBuf choices[3] = {"Off", "On", ""};
+		static const StringList oVals(&choices[0], &choices[2]);
+		return &oVals;
+	}
+}
+
+
+ThMLStrongs::ThMLStrongs() : SWOptionFilter(oName, oTip, oValues()) {
 }
 
 
