@@ -1,10 +1,25 @@
 /******************************************************************************
  *
- * thmlstrongs -	SWFilter descendant to hide or show strongs number
- *			in a ThML module.
+ *  thmlwordjs.cpp -	SWFilter descendant to ???
+ *
+ * $Id: thmlwordjs.cpp 2980 2013-09-14 21:51:47Z scribe $
+ *
+ * Copyright 2005-2013 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <thmlwordjs.h>
@@ -14,17 +29,23 @@
 #include <utilstr.h>
 #include <versekey.h>
 
+
 SWORD_NAMESPACE_START
 
-const char oName[] = "Word Javascript";
-const char oTip[] = "Toggles Word Javascript data";
+namespace {
 
-const SWBuf choices[3] = {"Off", "On", ""};
-const StringList oValues(&choices[0], &choices[2]);
+	static const char oName[] = "Word Javascript";
+	static const char oTip[]  = "Toggles Word Javascript data";
+
+	static const StringList *oValues() {
+		static const SWBuf choices[3] = {"Off", "On", ""};
+		static const StringList oVals(&choices[0], &choices[2]);
+		return &oVals;
+	}
+}
 
 
-ThMLWordJS::ThMLWordJS() : SWOptionFilter(oName, oTip, &oValues) {
-	setOptionValue("Off");
+ThMLWordJS::ThMLWordJS() : SWOptionFilter(oName, oTip, oValues()) {
 
      defaultGreekLex   = 0;
      defaultHebLex     = 0;
@@ -43,19 +64,17 @@ char ThMLWordJS::processText(SWBuf &text, const SWKey *key, const SWModule *modu
 		char token[2112]; // cheese.  Fix.
 		int tokpos = 0;
 		bool intoken = false;
-		bool lastspace = false;
 		int word = 1;
 		char val[128];
 		char *valto;
 		char *ch;
 		char wordstr[5];
 		unsigned int textStart = 0, lastAppendLen = 0, textEnd = 0;
-		char gh = 0;
 		SWBuf tmp;
 		bool newText = false;
 		bool needWordOut = false;
 		AttributeValue *wordAttrs = 0;
-		SWBuf modName = (module)?module->Name():"";
+		SWBuf modName = (module)?module->getName():"";
 		SWBuf wordSrcPrefix = modName;
 		
 		const SWBuf orig = text;
@@ -146,7 +165,7 @@ char ThMLWordJS::processText(SWBuf &text, const SWKey *key, const SWModule *modu
 						gh = isdigit(strong[0]) ? 0:strong[0];
 						if (!gh) {
 							if (vkey) {
-								gh = vkey->Testament() ? 'H' : 'G';
+								gh = vkey->getTestament() ? 'H' : 'G';
 							}
 						}
 						else strong << 1;
@@ -165,7 +184,7 @@ char ThMLWordJS::processText(SWBuf &text, const SWKey *key, const SWModule *modu
 						if (sLex) {
 							// we can pass the real lex name in, but we have some
 							// aliases in the javascript to optimize bandwidth
-							lexName = sLex->Name();
+							lexName = sLex->getName();
 							if (lexName == "StrongsGreek")
 								lexName = "G";
 							if (lexName == "StrongsHebrew")
@@ -174,12 +193,12 @@ char ThMLWordJS::processText(SWBuf &text, const SWKey *key, const SWModule *modu
 						SWBuf wordID;
 						if (vkey) {
 							// optimize for bandwidth and use only the verse as the unique entry id
-							wordID.appendFormatted("%d", vkey->Verse());
+							wordID.appendFormatted("%d", vkey->getVerse());
 						}
 						else {
 							wordID = key->getText();
 						}
-						for (int i = 0; i < wordID.size(); i++) {
+						for (unsigned int i = 0; i < wordID.size(); i++) {
 							if ((!isdigit(wordID[i])) && (!isalpha(wordID[i]))) {
 								wordID[i] = '_';
 							}
@@ -192,10 +211,11 @@ char ThMLWordJS::processText(SWBuf &text, const SWKey *key, const SWModule *modu
 
 
 
+							if (!sMorph) sMorph = 0;	// avoid unused warnings for now
 /*
 							if (sMorph) {
 								SWBuf popMorph = "<a onclick=\"";
-								popMorph.appendFormatted("p(\'%s\',\'%s\','%s','');\" >%s</a>", sMorph->Name(), morph.c_str(), wordID.c_str(), morph.c_str());
+								popMorph.appendFormatted("p(\'%s\',\'%s\','%s','');\" >%s</a>", sMorph->getName(), morph.c_str(), wordID.c_str(), morph.c_str());
 								morph = popMorph;
 							}
 */
@@ -223,7 +243,6 @@ char ThMLWordJS::processText(SWBuf &text, const SWKey *key, const SWModule *modu
 			}
 			else	{
 				text += *from;
-				lastspace = (*from == ' ');
 			}
 		}
 
@@ -241,7 +260,7 @@ char ThMLWordJS::processText(SWBuf &text, const SWKey *key, const SWModule *modu
 			gh = isdigit(strong[0]) ? 0:strong[0];
 			if (!gh) {
 				if (vkey) {
-					gh = vkey->Testament() ? 'H' : 'G';
+					gh = vkey->getTestament() ? 'H' : 'G';
 				}
 			}
 			else strong << 1;
@@ -257,7 +276,7 @@ char ThMLWordJS::processText(SWBuf &text, const SWKey *key, const SWModule *modu
 			if (sLex) {
 				// we can pass the real lex name in, but we have some
 				// aliases in the javascript to optimize bandwidth
-				lexName = sLex->Name();
+				lexName = sLex->getName();
 				if (lexName == "StrongsGreek")
 					lexName = "G";
 				if (lexName == "StrongsHebrew")
@@ -266,12 +285,12 @@ char ThMLWordJS::processText(SWBuf &text, const SWKey *key, const SWModule *modu
 			SWBuf wordID;
 			if (vkey) {
 				// optimize for bandwidth and use only the verse as the unique entry id
-				wordID.appendFormatted("%d", vkey->Verse());
+				wordID.appendFormatted("%d", vkey->getVerse());
 			}
 			else {
 				wordID = key->getText();
 			}
-			for (int i = 0; i < wordID.size(); i++) {
+			for (unsigned int i = 0; i < wordID.size(); i++) {
 				if ((!isdigit(wordID[i])) && (!isalpha(wordID[i]))) {
 					wordID[i] = '_';
 				}
