@@ -2,7 +2,7 @@
  *
  * utf16utf8.cpp -	SWFilter descendant to convert UTF-16 to UTF-8
  *
- * $Id: utf16utf8.cpp 2980 2013-09-14 21:51:47Z scribe $
+ * $Id: utf16utf8.cpp 3157 2014-04-17 03:56:12Z greg.hellings $
  *
  * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -21,9 +21,6 @@
  */
 
 
-#include <stdlib.h>
-#include <stdio.h>
-
 #include <utf16utf8.h>
 #include <swbuf.h>
 
