@@ -2,7 +2,7 @@
  *
  *  utf8latin1.cpp -	SWFilter descendant to convert UTF-8 to Latin-1
  *
- * $Id: utf8latin1.cpp 2980 2013-09-14 21:51:47Z scribe $
+ * $Id: utf8latin1.cpp 3157 2014-04-17 03:56:12Z greg.hellings $
  *
  * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -20,9 +20,6 @@
  *
  */
 
-#include <stdlib.h>
-#include <stdio.h>
-
 #include <utf8latin1.h>
 #include <swbuf.h>
 
