@@ -3,7 +3,7 @@
  *  utf8nfkd.cpp -	SWFilter descendant to perform NFKD (compatability
  *			decomposition normalization) on UTF-8 text
  *
- * $Id: utf8nfkd.cpp 2980 2013-09-14 21:51:47Z scribe $
+ * $Id: utf8nfkd.cpp 3157 2014-04-17 03:56:12Z greg.hellings $
  *
  * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,10 +23,6 @@
 
 #ifdef _ICU_
 
-#include <stdlib.h>
-
-#include <utilstr.h>
-
 #include <utf8nfkd.h>
 #include <swbuf.h>
 
