@@ -2,7 +2,7 @@
  *
  *  utf8utf16.cpp -	SWFilter descendant to convert UTF-8 to UTF-16
  *
- * $Id: utf8utf16.cpp 2980 2013-09-14 21:51:47Z scribe $
+ * $Id: utf8utf16.cpp 3157 2014-04-17 03:56:12Z greg.hellings $
  *
  * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -20,10 +20,7 @@
  *
  */
 
-#include <stdlib.h>
-#include <stdio.h>
 
-#include <sysdata.h>
 #include <utf8utf16.h>
 #include <utilstr.h>
 #include <swbuf.h>
@@ -68,7 +65,6 @@ char UTF8UTF16::processText(SWBuf &text, const SWKey *key, const SWModule *modul
 	text.setSize(text.size()-2);
 	   
 	return 0;
-
 }
 
 SWORD_NAMESPACE_END
