@@ -1,9 +1,11 @@
 /******************************************************************************
- *  rawtext4.cpp - code for class 'RawText4'- a module that reads raw text
- *                 files: ot and nt using indexs ??.bks ??.cps ??.vss
  *
+ *  rawtext4.cpp -	code for class 'RawText4'- a module that reads raw text
+ *			files: ot and nt using indexs ??.bks ??.cps ??.vss
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: rawtext4.cpp 2980 2013-09-14 21:51:47Z scribe $
+ *
+ * Copyright 2007-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -31,24 +33,8 @@
 #include <versekey.h>
 #include <stringmgr.h>
 
-#include <regex.h>	// GNU
-#include <map>
-#include <list>
-#include <algorithm>
-
-#ifndef USELUCENE
-using std::map;
-using std::list;
-using std::find;
-#endif
-
 SWORD_NAMESPACE_START
 
-#ifndef USELUCENE
-typedef  map < SWBuf, list<long> > strlist;
-typedef list<long> longlist;
-#endif
-
 /******************************************************************************
  * RawText4 Constructor - Initializes data for instance of RawText4
  *
@@ -71,7 +57,7 @@ RawText4::~RawText4() {
 }
 
 
-bool RawText4::isWritable() {
+bool RawText4::isWritable() const {
 	return ((idxfp[0]->getFd() > 0) && ((idxfp[0]->mode & FileMgr::RDWR) == FileMgr::RDWR));
 }
 
@@ -83,16 +69,16 @@ bool RawText4::isWritable() {
  * RET: string buffer with verse
  */
 
-SWBuf &RawText4::getRawEntryBuf() {
+SWBuf &RawText4::getRawEntryBuf() const {
 	long  start = 0;
 	unsigned long size = 0;
 	VerseKey &key = getVerseKey();
 
-	findOffset(key.Testament(), key.TestamentIndex(), &start, &size);
+	findOffset(key.getTestament(), key.getTestamentIndex(), &start, &size);
 	entrySize = size;        // support getEntrySize call
 
 	entryBuf = "";
-	readText(key.Testament(), start, size, entryBuf);
+	readText(key.getTestament(), start, size, entryBuf);
 
 	rawFilter(entryBuf, 0);	// hack, decipher
 	rawFilter(entryBuf, &key);
@@ -106,14 +92,14 @@ SWBuf &RawText4::getRawEntryBuf() {
 
 void RawText4::setEntry(const char *inbuf, long len) {
 	VerseKey &key = getVerseKey();
-	doSetText(key.Testament(), key.TestamentIndex(), inbuf, len);
+	doSetText(key.getTestament(), key.getTestamentIndex(), inbuf, len);
 }
 
 
 void RawText4::linkEntry(const SWKey *inkey) {
 	VerseKey &destkey = getVerseKey();
 	const VerseKey *srckey = &getVerseKey(inkey);
-	doLinkEntry(destkey.Testament(), destkey.TestamentIndex(), srckey->TestamentIndex());
+	doLinkEntry(destkey.getTestament(), destkey.getTestamentIndex(), srckey->getTestamentIndex());
 }
 
 
@@ -125,7 +111,7 @@ void RawText4::linkEntry(const SWKey *inkey) {
 
 void RawText4::deleteEntry() {
 	VerseKey &key = getVerseKey();
-	doSetText(key.Testament(), key.TestamentIndex(), "");
+	doSetText(key.getTestament(), key.getTestamentIndex(), "");
 }
 
 /******************************************************************************
@@ -141,7 +127,7 @@ void RawText4::increment(int steps) {
 	unsigned long size;
 	VerseKey *tmpkey = &getVerseKey();
 
-	findOffset(tmpkey->Testament(), tmpkey->TestamentIndex(), &start, &size);
+	findOffset(tmpkey->getTestament(), tmpkey->getTestamentIndex(), &start, &size);
 
 	SWKey lastgood = *tmpkey;
 	while (steps) {
@@ -151,12 +137,12 @@ void RawText4::increment(int steps) {
 		(steps > 0) ? ++(*key) : --(*key);
 		tmpkey = &getVerseKey();
 
-		if ((error = key->Error())) {
+		if ((error = key->popError())) {
 			*key = lastgood;
 			break;
 		}
-		long index = tmpkey->TestamentIndex();
-		findOffset(tmpkey->Testament(), index, &start, &size);
+		long index = tmpkey->getTestamentIndex();
+		findOffset(tmpkey->getTestament(), index, &start, &size);
 		if (
 			(((laststart != start) || (lastsize != size))	// we're a different entry
 //				&& (start > 0)
@@ -174,10 +160,10 @@ bool RawText4::isLinked(const SWKey *k1, const SWKey *k2) const {
 	unsigned long size1, size2;
 	VerseKey *vk1 = &getVerseKey(k1);
 	VerseKey *vk2 = &getVerseKey(k2);
-	if (vk1->Testament() != vk2->Testament()) return false;
+	if (vk1->getTestament() != vk2->getTestament()) return false;
 
-	findOffset(vk1->Testament(), vk1->TestamentIndex(), &start1, &size1);
-	findOffset(vk2->Testament(), vk2->TestamentIndex(), &start2, &size2);
+	findOffset(vk1->getTestament(), vk1->getTestamentIndex(), &start1, &size1);
+	findOffset(vk2->getTestament(), vk2->getTestamentIndex(), &start2, &size2);
 	return start1 == start2;
 }
 
@@ -186,7 +172,7 @@ bool RawText4::hasEntry(const SWKey *k) const {
 	unsigned long size;
 	VerseKey *vk = &getVerseKey(k);
 
-	findOffset(vk->Testament(), vk->TestamentIndex(), &start, &size);
+	findOffset(vk->getTestament(), vk->getTestamentIndex(), &start, &size);
 	return size;
 }
 
