@@ -1,8 +1,11 @@
 /******************************************************************************
- *  swtext.cpp  - code for base class 'SWText'- The basis for all text modules
  *
+ *  swtext.cpp -	code for base class 'SWText'- The basis for all text
+ *			modules
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: swtext.cpp 2893 2013-07-16 03:07:02Z scribe $
+ *
+ * Copyright 1997-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -38,9 +41,9 @@ SWText::SWText(const char *imodname, const char *imoddesc, SWDisplay *idisp, SWT
 	this->versification = 0;
 	stdstr(&(this->versification), versification);
 	delete key;
-	key = (VerseKey *)CreateKey();
-	tmpVK1 = (VerseKey *)CreateKey();
-	tmpVK2 = (VerseKey *)CreateKey();
+	key = (VerseKey *)createKey();
+	tmpVK1 = (VerseKey *)createKey();
+	tmpVK2 = (VerseKey *)createKey();
         tmpSecond = false;
 	skipConsecutiveLinks = false;
 }
@@ -58,10 +61,10 @@ SWText::~SWText() {
 
 
 /******************************************************************************
- * SWText CreateKey - Create the correct key (VerseKey) for use with SWText
+ * SWText createKey - Create the correct key (VerseKey) for use with SWText
  */
 
-SWKey *SWText::CreateKey() const {
+SWKey *SWText::createKey() const {
 	VerseKey *vk = new VerseKey();
 
 	vk->setVersificationSystem(versification);
@@ -70,24 +73,22 @@ SWKey *SWText::CreateKey() const {
 }
 
 
-long SWText::Index() const {
+long SWText::getIndex() const {
 	VerseKey *key = &getVerseKey();
-	entryIndex = key->Index();
+	entryIndex = key->getIndex();
 
 	return entryIndex;
 }
 
-long SWText::Index(long iindex) {
+void SWText::setIndex(long iindex) {
 	VerseKey *key = &getVerseKey();
 
-	key->Testament(1);
-	key->Index(iindex);
+	key->setTestament(1);
+	key->setIndex(iindex);
 
 	if (key != this->key) {
 		this->key->copyFrom(*key);
 	}
-
-	return Index();
 }
 
 
@@ -108,7 +109,7 @@ VerseKey &SWText::getVerseKey(const SWKey *keyToConvert) const {
 		SWCATCH ( ... ) {	}
 		if (lkTest) {
 			SWTRY {
-				key = SWDYNAMIC_CAST(VerseKey, lkTest->GetElement());
+				key = SWDYNAMIC_CAST(VerseKey, lkTest->getElement());
 			}
 			SWCATCH ( ... ) {	}
 		}
