@@ -2,7 +2,7 @@
  *
  *  localetest.cpp -	
  *
- * $Id: localetest.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: localetest.cpp 3005 2014-01-09 04:06:11Z greg.hellings $
  *
  * Copyright 2000-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -33,9 +33,9 @@ int main(int argc, char **argv) {
 		exit(-1);
 	}
 
-	LocaleMgr lm;
+	LocaleMgr *lm = LocaleMgr::getSystemLocaleMgr();
 
-	std::cout << lm.translate(argv[2], argv[1]) << "\n";
+	std::cout << lm->translate(argv[2], argv[1]) << "\n";
 
 /*
 	VerseKey bla;
