@@ -1,7 +1,7 @@
 #!/bin/sh
 #******************************************************************************
 #
-# $Id: verseparsing.sh 2573 2010-10-17 21:15:48Z scribe $
+# $Id: verseparsing.sh 2796 2013-04-11 16:18:45Z scribe $
 #
 # Copyright 1998-2009 CrossWire Bible Society (http://www.crosswire.org)
 #	CrossWire Bible Society
@@ -18,6 +18,9 @@
 # General Public License for more details.
 #
 
+../parsekey "jn.1.1-2.5,9,3;7.9" en KJV ge 1
+../parsekey "jn.1.1-2.5" en KJV ge 1
+
 ../parsekey "1jn.2.3" en KJV ge 1
 ../parsekey "1 jn.2.3" en KJV ge 1
 ../parsekey "Ijn.2.3" en KJV ge 1
@@ -82,19 +85,31 @@
 ../parsekey "1Jn 1:1 ; 3:10" en KJV ge 1
 ../parsekey "1Jn 1:1a ; 3:10b" en KJV ge 1
 
-### These two are not quite right yet
+### Suffix parsing
 ../parsekey "1Jn 1:1-2a; 3:10b-11" en KJV ge 1
 ../parsekey "1Jn 1:1c;3:10d-12e,13" en KJV ge 1
+../parsekey "Luke 2:45b-3:1a;3:1b-7;3:8-14;3:15-21a" en KJV ge 1
 
 ../parsekey "1Jn1.1f; 3:10ff" en KJV ge 1
 ../parsekey "1Jn1.1ff;3:10f" en KJV ge 1
 ../parsekey "1Jn1.1,8ff; 3:10-12,14f,17ff" en KJV ge 1
+../parsekey "1Jn2.3f." en KJV ge 1
+../parsekey "1Jn2.3ff." en KJV ge 1
 
 ### check for 'f' in book name which might trigger 'and following'
 ../parsekey "Song of 3:5" en KJV ge 1
 ../parsekey "Song of Sol 3:5" en KJV ge 1
 ../parsekey "Revelation of John 1:1" en KJV ge 1
 
+### check for 'inscriptio' and 'subscriptio' special chapters which parse to Book 0:0 and Book 1:0 respectively (for INTF)
+../parsekey "Matt.Inscriptio" en KJV ge 1 0 1
+../parsekey "Matt.Subscriptio" en KJV ge 1 0 1
+../parsekey "Matt Inscriptio" en KJV ge 1 0 1
+../parsekey "Matt  Inscriptio" en KJV ge 1 0 1
+../parsekey "Matt  subsc" en KJV ge 1 0 1
+
+
+
 en_abbrevs="
 Gen Genes Exod Ex Exo Lev Le Levi Num Nu Numb Deut Deu De Josh Jos Joshu
 Judg Jdg Judge Ruth Ru Rut 1Sam 1Sa 1Samu 2Sam 2Sa 2Samu 1Kgs 1Ki 1King
