@@ -1,5 +1,11 @@
-/*
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+/******************************************************************************
+ *
+ *  addgb.cpp -	Utility to create/modify a GenBook module by adding a single
+ *		entry
+ *
+ * $Id: addgb.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2002-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -81,7 +87,7 @@ int main(int argc, char **argv) {
 
   // Do some initialization stuff
   TreeKeyIdx *treeKey = new TreeKeyIdx(argv[2]);
-  if (treeKey->Error()) {
+  if (treeKey->popError()) {
     treeKey->create(argv[2]);
     delete treeKey;
     treeKey = new TreeKeyIdx(argv[2]);
