@@ -1,5 +1,10 @@
-/*
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+/******************************************************************************
+ *
+ *  addld.cpp -	Utility to build/modify an LD module by adding a single entry
+ *
+ * $Id: addld.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2000-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -79,8 +84,8 @@ int main(int argc, char **argv) {
     if (fourbyte) {
       char buffer[1048576];  //this is the max size of any entry
       RawLD4 mod(argv[2]);	// open our datapath with our RawText driver.
-      SWKey* key = mod.CreateKey();
-      key->Persist(1);      // the magical setting
+      SWKey* key = mod.createKey();
+      key->setPersist(true);      // the magical setting
       
       // Set our VerseKey
       *key = argv[3];
@@ -99,8 +104,8 @@ int main(int argc, char **argv) {
 #ifndef EXCLUDEZLIB
       char buffer[1048576];  //this is the max size of any entry
       zLD mod(argv[2], 0, 0, 200, new ZipCompress());	// open our datapath with our RawText driver.
-      SWKey* key = mod.CreateKey();
-      key->Persist(1);      // the magical setting
+      SWKey* key = mod.createKey();
+      key->setPersist(true);      // the magical setting
       
       // Set our VerseKey
       *key = argv[3];
@@ -122,8 +127,8 @@ int main(int argc, char **argv) {
     else {
       char buffer[65536];  //this is the max size of any entry
       RawLD mod(argv[2]);	// open our datapath with our RawText driver.
-      SWKey* key = mod.CreateKey();
-      key->Persist(1);      // the magical setting
+      SWKey* key = mod.createKey();
+      key->setPersist(true);      // the magical setting
       
       // Set our VerseKey
       *key = argv[3];
@@ -145,8 +150,8 @@ int main(int argc, char **argv) {
     // Do some initialization stuff
     if (fourbyte) {
       RawLD4 mod(argv[2]);	// open our datapath with our RawText driver.
-      SWKey* key = mod.CreateKey();
-      key->Persist(1);      // the magical setting
+      SWKey* key = mod.createKey();
+      key->setPersist(true);      // the magical setting
       
       *key = argv[3];
 	 mod.setKey(*key);
@@ -155,8 +160,8 @@ int main(int argc, char **argv) {
     }
     else if (compress) {
       zLD mod(argv[2]);	// open our datapath with our RawText driver.
-      SWKey* key = mod.CreateKey();
-      key->Persist(1);      // the magical setting
+      SWKey* key = mod.createKey();
+      key->setPersist(true);      // the magical setting
       
       *key = argv[3];
 	 mod.setKey(*key);
@@ -166,8 +171,8 @@ int main(int argc, char **argv) {
     }
     else {
       RawLD mod(argv[2]);	// open our datapath with our RawText driver.
-      SWKey* key = mod.CreateKey();
-      key->Persist(1);      // the magical setting
+      SWKey* key = mod.createKey();
+      key->setPersist(true);      // the magical setting
       
       *key = argv[3];
 	 mod.setKey(*key);
