@@ -2,7 +2,7 @@
  *
  *  corediatheke.h -	
  *
- * $Id: corediatheke.h 2900 2013-07-16 07:48:52Z chrislit $
+ * $Id: corediatheke.h 3189 2014-04-17 05:00:28Z greg.hellings $
  *
  * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -30,6 +30,7 @@
 
 #include "diathekemgr.h"
 #include <localemgr.h>
+#include <swlocale.h>
 
 #define QT_BIBLE 1
 #define QT_COMM 2
@@ -62,6 +63,11 @@
 #define ST_REGEX 1     //  0
 #define ST_PHRASE 2    // -1
 #define ST_MULTIWORD 3 // -2
+#define ST_ENTRYATTRIB 4 // -3
+#define ST_CLUCENE 5 // -4
+#define ST_MULTILEMMA 6 // -5
+
+
 
 using namespace std;
 
