@@ -1,7 +1,10 @@
 /******************************************************************************
- *  diafiltmgr.cpp
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ *  diafiltmgr.cpp -	DiathekeFilterMgr
+ *
+ * $Id: diafiltmgr.cpp 2843 2013-06-29 11:22:27Z chrislit $
+ *
+ * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -23,7 +26,6 @@
 #include <gbfthml.h>
 #include <thmlhtml.h>
 #include <gbfhtml.h>
-#include <plainhtml.h>
 #include <thmlhtmlhref.h>
 #include <gbfhtmlhref.h>
 #include <thmlrtf.h>
@@ -62,22 +64,22 @@ DiathekeFilterMgr::~DiathekeFilterMgr() {
 }
 
 void DiathekeFilterMgr::AddRenderFilters(SWModule *module, ConfigEntMap &section) {
-        switch (module->Markup()) {
+        switch (module->getMarkup()) {
         case FMT_THML:
                 if (fromthml)
-                        module->AddRenderFilter(fromthml);
+                        module->addRenderFilter(fromthml);
                 break;
         case FMT_GBF:
                 if (fromgbf)
-                        module->AddRenderFilter(fromgbf);
+                        module->addRenderFilter(fromgbf);
                 break;
         case FMT_PLAIN:
                 if (fromplain)
-                        module->AddRenderFilter(fromplain);
+                        module->addRenderFilter(fromplain);
                 break;
         case FMT_OSIS:
                 if (fromosis)
-                        module->AddRenderFilter(fromosis);
+                        module->addRenderFilter(fromosis);
                 break;
         }
 	EncodingFilterMgr::AddRenderFilters(module, section);
@@ -97,19 +99,19 @@ char DiathekeFilterMgr::Markup(char mark) {
                 CreateFilters(markup);
 
                 for (module = getParentMgr()->Modules.begin(); module != getParentMgr()->Modules.end(); module++)
-                        switch (module->second->Markup()) {
+                        switch (module->second->getMarkup()) {
                         case FMT_THML:
                                 if (oldthml != fromthml) {
                                         if (oldthml) {
                                                 if (!fromthml) {
-                                                        module->second->RemoveRenderFilter(oldthml);
+                                                        module->second->removeRenderFilter(oldthml);
                                                 }
                                                 else {
-                                                        module->second->ReplaceRenderFilter(oldthml, fromthml);
+                                                        module->second->replaceRenderFilter(oldthml, fromthml);
                                                 }
                                         }
                                         else if (fromthml) {
-                                                module->second->AddRenderFilter(fromthml);
+                                                module->second->addRenderFilter(fromthml);
                                         }
                                 }
                                 break;
@@ -117,14 +119,14 @@ char DiathekeFilterMgr::Markup(char mark) {
                                 if (oldgbf != fromgbf) {
                                         if (oldgbf) {
                                                 if (!fromgbf) {
-                                                        module->second->RemoveRenderFilter(oldgbf);
+                                                        module->second->removeRenderFilter(oldgbf);
                                                 }
                                                 else {
-                                                        module->second->ReplaceRenderFilter(oldgbf, fromgbf);
+                                                        module->second->replaceRenderFilter(oldgbf, fromgbf);
                                                 }
                                         }
                                         else if (fromgbf) {
-                                                module->second->AddRenderFilter(fromgbf);
+                                                module->second->addRenderFilter(fromgbf);
                                         }
                                         break;
                                 }
@@ -132,14 +134,14 @@ char DiathekeFilterMgr::Markup(char mark) {
                                 if (oldplain != fromplain) {
                                         if (oldplain) {
                                                 if (!fromplain) {
-                                                        module->second->RemoveRenderFilter(oldplain);
+                                                        module->second->removeRenderFilter(oldplain);
                                                 }
                                                 else {
-                                                        module->second->ReplaceRenderFilter(oldplain, fromplain);
+                                                        module->second->replaceRenderFilter(oldplain, fromplain);
                                                 }
                                         }
                                         else if (fromplain) {
-                                                module->second->AddRenderFilter(fromplain);
+                                                module->second->addRenderFilter(fromplain);
                                         }
                                         break;
                                 }
@@ -147,14 +149,14 @@ char DiathekeFilterMgr::Markup(char mark) {
                                 if (oldosis != fromosis) {
                                         if (oldosis) {
                                                 if (!fromosis) {
-                                                        module->second->RemoveRenderFilter(oldosis);
+                                                        module->second->removeRenderFilter(oldosis);
                                                 }
                                                 else {
-                                                        module->second->ReplaceRenderFilter(oldosis, fromosis);
+                                                        module->second->replaceRenderFilter(oldosis, fromosis);
                                                 }
                                         }
                                         else if (fromosis) {
-                                                module->second->AddRenderFilter(fromosis);
+                                                module->second->addRenderFilter(fromosis);
                                         }
                                         break;
                                 }
@@ -200,7 +202,7 @@ void DiathekeFilterMgr::CreateFilters(char markup) {
                         fromosis = NULL;
                         break;
                 case FMT_HTML:
-                        fromplain = new PLAINHTML();
+                        fromplain = NULL;
                         fromthml = new ThMLHTML();
                         fromgbf = new GBFHTML();
                         fromosis = NULL;
