@@ -1,5 +1,10 @@
-/*
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+/******************************************************************************
+ *
+ *  emptyvss.cpp -	Utility to list empty verses in a module
+ *
+ * $Id: emptyvss.cpp 2931 2013-07-31 13:07:26Z scribe $
+ *
+ * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -62,15 +67,15 @@ int main(int argc, char **argv) {
 		exit(-3);
 	}
 
-	vkey->Headings(1);	// turn on mod/testmnt/book/chap headings
+	vkey->setIntros(false);	// turn on mod/testmnt/book/chap headings
 
 	(*mod) = TOP;
 
-	while (!mod->Error()) {
+	while (!mod->popError()) {
 	  
-	  if (vkey->Verse())
-	    if (!strlen ((const char *)(*mod)))
-	      std::cout << *vkey << std::endl;
-	  (*mod)++;
+	if (vkey->getVerse())
+		if (!mod->renderText().length())
+			std::cout << *vkey << std::endl;
+		(*mod)++;
 	}
 }
