@@ -1,5 +1,10 @@
-/*
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+/******************************************************************************
+ *
+ *  genbookutil.cpp -	
+ *
+ * $Id: genbookutil.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2002-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -82,7 +87,7 @@ void assurePath(TreeKeyIdx *treeKey) {
 
 void viewEntryText(RawGenBook *book) {
 	std::cout << "\n";
-	std::cout << book->RenderText();
+	std::cout << book->renderText();
 	std::cout << "\n";
 }
 
@@ -158,7 +163,7 @@ int main(int argc, char **argv) {
 
 	TreeKeyIdx *treeKey = new TreeKeyIdx(argv[1]);
 
-	if (treeKey->Error()) {
+	if (treeKey->popError()) {
 		RawGenBook::createModule(argv[1]);
 	}
 	delete treeKey;
