@@ -1,5 +1,10 @@
-/*
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+/******************************************************************************
+ *
+ *  imp2gbs.cpp -	Utility to import GenBooks in IMP format
+ *
+ * $Id: imp2gbs.cpp 2980 2013-09-14 21:51:47Z scribe $
+ *
+ * Copyright 2002-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -203,7 +208,7 @@ void writeEntry(SWModule *book, SWBuf keyBuffer, SWBuf entBuffer) {
 	book->setKey(keyBuffer.c_str());
 
 	// check to see if we already have an entry
-	for (int i = 2; book->getKey()->Error() != KEYERR_OUTOFBOUNDS; i++) {
+	for (int i = 2; book->getKey()->popError() != KEYERR_OUTOFBOUNDS; i++) {
 		SWBuf key;
 		key.setFormatted("%s {%d}", keyBuffer.c_str(), i);
 		std::cout << "dup key, trying: " << key << std::endl;
