@@ -1,5 +1,10 @@
-/*
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+/******************************************************************************
+ *
+ *  installmgr.cpp -	commandline InstallMgr utility
+ *
+ * $Id: installmgr.cpp 2932 2013-07-31 14:07:01Z scribe $
+ *
+ * Copyright 2003-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -21,7 +26,7 @@
 
 #include <swmgr.h>
 #include <installmgr.h>
-#include <ftptrans.h>
+#include <remotetrans.h>
 #include <filemgr.h>
 #include <iostream>
 #include <map>
@@ -81,12 +86,12 @@ virtual bool isUserDisclaimerConfirmed() const {
 
 class MyStatusReporter : public StatusReporter {
 	int last;
-        virtual void statusUpdate(double dltotal, double dlnow) {
-		int p = 74 * (int)(dlnow / dltotal);
+        virtual void update(unsigned long totalBytes, unsigned long completedBytes) {
+		int p = (totalBytes > 0) ? (int)(74.0 * ((double)completedBytes / (double)totalBytes)) : 0;
 		for (;last < p; ++last) {
 			if (!last) {
 				SWBuf output;
-				output.setFormatted("[ File Bytes: %ld", (long)dltotal);
+				output.setFormatted("[ File Bytes: %ld", totalBytes);
 				while (output.size() < 75) output += " ";
 				output += "]";
 				cout << output.c_str() << "\n ";
@@ -101,7 +106,7 @@ class MyStatusReporter : public StatusReporter {
 		while (output.size() < 75) output += " ";
 		output += "]";
 		cout << "\n" << output.c_str() << "\n ";
-		int p = 74 * (int)((double)completedBytes/totalBytes);
+		int p = (int)(74.0 * (double)completedBytes/totalBytes);
 		for (int i = 0; i < p; ++i) { cout << "="; }
 		cout << "\n\n" << message << "\n";
 		last = 0;
@@ -203,7 +208,7 @@ void uninstallModule(const char *modName) {
 		finish(-2);
 	}
 	module = it->second;
-	installMgr->removeModule(mgr, module->Name());
+	installMgr->removeModule(mgr, module->getName());
 	cout << "Removed module: [" << modName << "]\n";
 }
 
@@ -248,7 +253,7 @@ void listModules(SWMgr *otherMgr = 0, bool onlyNewAndUpdates = false) {
 		if (it->second & InstallMgr::MODSTAT_UPDATED) status = "+";
 
 		if (!onlyNewAndUpdates || status == "*" || status == "+") {
-			cout << status << "[" << module->Name() << "]  \t(" << version << ")  \t- " << module->Description() << "\n";
+			cout << status << "[" << module->getName() << "]  \t(" << version << ")  \t- " << module->getDescription() << "\n";
 		}
 	}
 }
@@ -290,10 +295,10 @@ void remoteInstallModule(const char *sourceName, const char *modName) {
 	}
 	module = it->second;
 
-	int error = installMgr->installModule(mgr, 0, module->Name(), is);
+	int error = installMgr->installModule(mgr, 0, module->getName(), is);
 	if (error) {
-		cout << "\nError installing module: [" << module->Name() << "] (write permissions?)\n";
-	} else cout << "\nInstalled module: [" << module->Name() << "]\n";
+		cout << "\nError installing module: [" << module->getName() << "] (write permissions?)\n";
+	} else cout << "\nInstalled module: [" << module->getName() << "]\n";
 }
 
 
@@ -307,10 +312,10 @@ void localDirInstallModule(const char *dir, const char *modName) {
 		finish(-4);
 	}
 	module = it->second;
-	int error = installMgr->installModule(mgr, dir, module->Name());
+	int error = installMgr->installModule(mgr, dir, module->getName());
 	if (error) {
-		cout << "\nError installing module: [" << module->Name() << "] (write permissions?)\n";
-	} else cout << "\nInstalled module: [" << module->Name() << "]\n";
+		cout << "\nError installing module: [" << module->getName() << "] (write permissions?)\n";
+	} else cout << "\nInstalled module: [" << module->getName() << "]\n";
 }
 
 
@@ -324,16 +329,16 @@ void usage(const char *progName, const char *error) {
 		"\t\t\t\t\t\tWARNING: overwrites existing.\n"
 		"\t-sc\t\t\t\tsync config with known remote repo list\n"
 		"\t\t\t\t\t\tNOTE: also creates if none exists\n"
-		"\t-d\t\t\t\tturn debug output on\n"
-		"\t-l\t\t\t\tlist installed modules\n"
-		"\t-u <modName>\t\t\tuninstall module\n"
 		"\t-s\t\t\t\tlist remote sources\n"
 		"\t-r  <remoteSrcName>\t\trefresh remote source\n"
 		"\t-rl <remoteSrcName>\t\tlist available modules from remote source\n"
 		"\t-rd <remoteSrcName>\t\tlist new/updated modules from remote source\n"
 		"\t-ri <remoteSrcName> <modName>\tinstall module from remote source\n"
+		"\t-l\t\t\t\tlist installed modules\n"
+		"\t-u <modName>\t\t\tuninstall module\n"
 		"\t-ll <path>\t\t\tlist available modules at local path\n"
 		"\t-li <path> <modName>\t\tinstall module from local path\n"
+		"\t-d\t\t\t\tturn debug output on\n"
 		, (progName ? progName : "installmgr"));
 	finish(-1);
 }
