@@ -1,5 +1,11 @@
-/*
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+/******************************************************************************
+ *
+ *  vs2osisreftext.cpp -	Utility to translate a verse reference to an
+ *				osisRef
+ *
+ * $Id: vs2osisreftxt.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2008-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -42,13 +48,13 @@ int main(int argc, char **argv) {
 
 	DefaultVSKey = "jas3:1";
 	
-	ListKey verses = DefaultVSKey.ParseVerseList(argv[1], DefaultVSKey, true);
+	ListKey verses = DefaultVSKey.parseVerseList(argv[1], DefaultVSKey, true);
 
 	std::cout << verses.getOSISRefRangeText() << "\n";
 
 	if (argc > 3) {
 		verses.setText(argv[3]);
-		std::cout << "Verse is" << ((verses.Error()) ? " NOT" : "") << " in set.\n\n";
+		std::cout << "Verse is" << ((verses.popError()) ? " NOT" : "") << " in set.\n\n";
 	}
 	
 	return 0;
